@@ -23,9 +23,13 @@
 */                                                                            
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
+#include <time.h>
 #include <SDL_timer.h>
 #include <signal.h>
 #include <math.h>
+#include <string.h>
+#include <time.h>
 #ifdef SOUND
 #include "SDL_mixer.h"
 #endif
@@ -37,10 +41,12 @@
 #include "font.h"
 #include "options.h"
 
+#ifndef VERSION
+#define VERSION "1.5.1"
+#endif
 #define MAX_PLAYER_NUM 2
 #define FOREGROUND_TILE_NUM 8
 #define MAX_SHOTNUM 50
-#define NUMBER_OF_LEVELS 21
 #define BPP 0
 #define RR 3                 //this is a value of unprecision for the racer collision
 
@@ -48,6 +54,7 @@
        player user[MAX_PLAYER_NUM]; int pl=0,playernum=2;
     //general setting
        int final=1,fullscreen=1,pageflip=0,sound=1,precision=10,fps=0,particle=1,mode,dofadeout=1,levelset=0;
+       const int NUMBER_OF_LEVELS[2]={21,9};
     //level settings
        float gravity=0,turbo=5,laser_switch;
        int startx,starty;
@@ -77,8 +84,10 @@
        int stop=0,stop2=0,infox,infoy,shotnum=0,cannonnum;
        Sint32 now,lifetime=800000,last_lifetime,NextParticle;
        char text[200];
-       int i,y,x,time_bonus;
+       int y,x,time_bonus;
        shot_type shot[MAX_SHOTNUM];
+       cannon_type cannon;
+
 
 void ComplainAndExit(void);
 
@@ -135,7 +144,7 @@ void corner_collision(  Uint8 xblock, Uint8 yblock)
 
 void kollision()  //calcualtes all collisions
 {
-  Uint8 x,y,x2,y2,xbig,ybig,sticky;
+  Uint8 x,y,x2,y2,sticky;
   SDL_Rect reblit_back;
   if (( keys[user[pl].extra] == SDL_PRESSED )&&(user[pl].sticky_possible)) sticky=1; else sticky=0;
   if (already) {already=0;} else
@@ -144,28 +153,36 @@ void kollision()  //calcualtes all collisions
 //wall
       if (((map[levelnum][y][x]==1)||(map[levelnum][y][x]>10)||(map[levelnum][y][x]==8))&&((user[pl].realx+30>x*40)&&(user[pl].realx<x*40+38)&&(user[pl].realy+30>y*40)&&(user[pl].realy<y*40+38))&&(!stop))
       { 
-      // edges
-	if ((user[pl].realy+15<y*40)&&(user[pl].realy+30-RR>y*40)&&(!already)&&
-	    (user[pl].realx+15<(x+1)*40)&&(user[pl].realx+15>x*40)&&(map[levelnum][y-1][x]!=1))
-	    if (sticky) {user[pl].yspeed*=0.1;user[pl].xspeed*=0.1;} else if (user[pl].yspeed>0) {user[pl].yspeed=-user[pl].yspeed;already=1;}
-	if ((user[pl].realx+15>(x+1)*40)&&(user[pl].realx+RR<(x+1)*40)&&(!already)&&
-	    (user[pl].realy+15<(y+1)*40)&&(user[pl].realy+15>y*40)&&(map[levelnum][y][x+1]!=1))	    
-	    if (sticky) {user[pl].yspeed*=0.1;user[pl].xspeed*=0.1;} else if (user[pl].xspeed<0) {user[pl].xspeed=-user[pl].xspeed;already=1;}
-	if ((user[pl].realy+15>(y+1)*40)&&(user[pl].realy+RR<(y+1)*40)&&(!already)&&
-	    (user[pl].realx+15<(x+1)*40)&&(user[pl].realx+15>x*40)&&(map[levelnum][y+1][x]!=1))
-	    if (sticky) {user[pl].yspeed*=0.1;user[pl].xspeed*=0.1;} else if (user[pl].yspeed<0) {user[pl].yspeed=-user[pl].yspeed;already=1;}
-	if ((user[pl].realx+15<x*40)&&(user[pl].realx+30-RR>x*40)&&(!already)&&
-	    (user[pl].realy+15<(y+1)*40)&&(user[pl].realy+15>y*40)&&(map[levelnum][y][x-1]!=1))	    
-	    if (sticky) {user[pl].yspeed*=0.1;user[pl].xspeed*=0.1;} else if (user[pl].xspeed>0) {user[pl].xspeed=-user[pl].xspeed;already=1;}
-      // corners
-        if ((user[pl].realx+15>(x+1)*40)&&(user[pl].realy+15<y*40)&&(!already)&&(map[levelnum][y][x+1]!=1)&&(map[levelnum][y-1][x]!=1))
-	  /*if ((user[pl].xspeed<0)&&(user[pl].yspeed>0))*/ corner_collision(x+1,y);
-        if ((user[pl].realx+15<x*40)&&(user[pl].realy+15<y*40)&&(!already)&&(map[levelnum][y][x-1]!=1)&&(map[levelnum][y-1][x]!=1))
-	  /*if ((user[pl].xspeed>0)&&(user[pl].yspeed>0))*/ corner_collision(x,y);
-        if ((user[pl].realx+15>(x+1)*40)&&(user[pl].realy+15>(y+1)*40)&&(!already)&&(map[levelnum][y][x+1]!=1)&&(map[levelnum][y+1][x]!=1))
-	  /*if ((user[pl].xspeed<0)&&(user[pl].yspeed<0))*/ corner_collision(x+1,y+1);
-        if ((user[pl].realx+15<x*40)&&(user[pl].realy+15>(y+1)*40)&&(!already)&&(map[levelnum][y][x-1]!=1)&&(map[levelnum][y+1][x]!=1))
-	  /*if ((user[pl].xspeed>0)&&(user[pl].yspeed<0))*/ corner_collision(x,y+1);
+		  // edges
+		  if ((user[pl].realy+15<y*40)&&(user[pl].realy+30-RR>y*40)&&(!already)&&
+			  (user[pl].realx+15<(x+1)*40)&&(user[pl].realx+15>x*40)&&(map[levelnum][y-1][x]!=1))
+		  {
+			  if (sticky) {user[pl].yspeed*=0.1;user[pl].xspeed*=0.1;} else if (user[pl].yspeed>0) {user[pl].yspeed=-user[pl].yspeed;already=1;}
+		  }
+		  if ((user[pl].realx+15>(x+1)*40)&&(user[pl].realx+RR<(x+1)*40)&&(!already)&&
+			  (user[pl].realy+15<(y+1)*40)&&(user[pl].realy+15>y*40)&&(map[levelnum][y][x+1]!=1))	    
+		  {
+			  if (sticky) {user[pl].yspeed*=0.1;user[pl].xspeed*=0.1;} else if (user[pl].xspeed<0) {user[pl].xspeed=-user[pl].xspeed;already=1;}
+		  }
+		  if ((user[pl].realy+15>(y+1)*40)&&(user[pl].realy+RR<(y+1)*40)&&(!already)&&
+			  (user[pl].realx+15<(x+1)*40)&&(user[pl].realx+15>x*40)&&(map[levelnum][y+1][x]!=1))
+		  {
+			  if (sticky) {user[pl].yspeed*=0.1;user[pl].xspeed*=0.1;} else if (user[pl].yspeed<0) {user[pl].yspeed=-user[pl].yspeed;already=1;}
+		  }
+		  if ((user[pl].realx+15<x*40)&&(user[pl].realx+30-RR>x*40)&&(!already)&&
+			  (user[pl].realy+15<(y+1)*40)&&(user[pl].realy+15>y*40)&&(map[levelnum][y][x-1]!=1))	    
+		  {
+			  if (sticky) {user[pl].yspeed*=0.1;user[pl].xspeed*=0.1;} else if (user[pl].xspeed>0) {user[pl].xspeed=-user[pl].xspeed;already=1;}
+		  }
+		  // corners
+		  if ((user[pl].realx+15>(x+1)*40)&&(user[pl].realy+15<y*40)&&(!already)&&(map[levelnum][y][x+1]!=1)&&(map[levelnum][y-1][x]!=1))
+			  /*if ((user[pl].xspeed<0)&&(user[pl].yspeed>0))*/ corner_collision(x+1,y);
+		  if ((user[pl].realx+15<x*40)&&(user[pl].realy+15<y*40)&&(!already)&&(map[levelnum][y][x-1]!=1)&&(map[levelnum][y-1][x]!=1))
+			  /*if ((user[pl].xspeed>0)&&(user[pl].yspeed>0))*/ corner_collision(x,y);
+		  if ((user[pl].realx+15>(x+1)*40)&&(user[pl].realy+15>(y+1)*40)&&(!already)&&(map[levelnum][y][x+1]!=1)&&(map[levelnum][y+1][x]!=1))
+			  /*if ((user[pl].xspeed<0)&&(user[pl].yspeed<0))*/ corner_collision(x+1,y+1);
+		  if ((user[pl].realx+15<x*40)&&(user[pl].realy+15>(y+1)*40)&&(!already)&&(map[levelnum][y][x-1]!=1)&&(map[levelnum][y+1][x]!=1))
+			  /*if ((user[pl].xspeed>0)&&(user[pl].yspeed<0))*/ corner_collision(x,y+1);
       }
       if (stop) {stop--;}
       if (stop2) {stop2--;}
@@ -297,7 +314,7 @@ void UndrawLaser(int update)
 {
   SDL_Rect src_rect;
  
-  Uint8 x,y,xbig,ybig;  
+  Uint8 x,y;  
   for (y=0;y<=14;y++) {
     for (x=0;x<=19;x++) {
       if (map[levelnum][y][x]==7){ 
@@ -317,7 +334,7 @@ void DrawLaser()
 {
   SDL_Rect src_rect;
  
-  Uint8 x,y,xbig,ybig;  
+  Uint8 x,y;  
   for (y=0;y<=14;y++) {
     for (x=0;x<=19;x++) {
       if (map[levelnum][y][x]==7){ 
@@ -420,8 +437,6 @@ void DrawExplosion()
 
 void checks_1p()
 {
-  int degree;
-
 //level end
   if ( user[pl].completed )
   {  
@@ -619,8 +634,6 @@ void HandleShots()
 
 void DisplayShots()
 {
-  SDL_Rect update[2];
-
   for (i=0;i<shotnum;i++)
     Blit(shot[i].x,shot[i].y,shot_pic[(int)shot[i].anim]);
 }
@@ -676,8 +689,6 @@ void blit_fore() //blits the leves foreground (used only one time per level)
 
 void LookForInfo() //looks for the info box in this level
 {
-  int i;
-  
   infox=-1;
   infoy=-1;
   cannon.x=-1;
@@ -846,18 +857,18 @@ void nextlevel() //selects the next level at random
   int i;
   finished[levelnum]=1;
   quit=1;
-  for (i=0;i<NUMBER_OF_LEVELS;i++) {
+  for (i=0;i<NUMBER_OF_LEVELS[levelset];i++) {
     if (finished[i]==0) {quit=0;}
   }
   if (!quit) {
     while (finished[levelnum]==1)
     {
-      levelnum=abrand(0,NUMBER_OF_LEVELS-1);
+      levelnum=abrand(0,NUMBER_OF_LEVELS[levelset]-1);
     }
     levels_completed++;
   } else {
     // reset all levels, if each level has been played one time
-    for (i=0;i<=NUMBER_OF_LEVELS;i++) {
+    for (i=0;i<=NUMBER_OF_LEVELS[levelset];i++) {
       int x,y;
 
       finished[i]=0;
@@ -871,7 +882,7 @@ void nextlevel() //selects the next level at random
       }
     }
     quit=0;
-    levelnum=abrand(0,NUMBER_OF_LEVELS-1);
+    levelnum=abrand(0,NUMBER_OF_LEVELS[levelset]-1);
   }
   if ((levels_completed==4)&&(mode!=1)) NextStage();
   sprintf(text,"BumpRace: Level #%d",levelnum);
@@ -957,17 +968,17 @@ void ScoreText()
     Uint32 x;
 
     x=260;
-    PutString(Screen, 400-TextWidth("---- COMPETITION SCORE ----")/2, 100, "---- COMPETITION SCORE ----");
+    PutString(Screen, 400-SFont_TextWidth("---- COMPETITION SCORE ----")/2, 100, "---- COMPETITION SCORE ----");
     PutString(Screen, x, 200, "Player 1:");
     PutString(Screen, x, 215, "Player 2:");
     sprintf(text, "%d levels completed", user[0].points);
-    PutString(Screen, x+280-TextWidth(text), 200, text);
+    PutString(Screen, x+280-SFont_TextWidth(text), 200, text);
     sprintf(text,"%d levels completed",user[1].points);
-    PutString(Screen, x+280-TextWidth(text), 215, text);
+    PutString(Screen, x+280-SFont_TextWidth(text), 215, text);
     if (user[0].points>user[1].points) sprintf(text,"Player 1 has won!");
 	else if (user[0].points<user[1].points) sprintf(text,"Player 2 has won!");
     	    else sprintf(text,"Draw Game!");
-    PutString(Screen, 400-TextWidth(text)/2, 240, text);
+    PutString(Screen, 400-SFont_TextWidth(text)/2, 240, text);
 }
 
 void score()
@@ -992,9 +1003,9 @@ void score()
 
 void InitSound()
 {
-  if ( Mix_OpenAudio(44100, AUDIO_S16, 2, 1024) < 0 ) 
+  if ( Mix_OpenAudio(44100, AUDIO_S16, 2, 4096) < 0 ) 
   {
-    fprintf(stderr,"Warning: Couldn't set 22025 Hz 16-bit audio\n- Reason: %s\n",SDL_GetError());
+    fprintf(stderr,"Warning: Couldn't set 44100 Hz 16-bit audio\n- Reason: %s\n",SDL_GetError());
     fprintf(stderr,"\t**\nSOUND TURNED OFF\n\t**\n");
     sound=0;
   }
@@ -1017,7 +1028,7 @@ void LoadSound()
 }
 #endif
 
-main(int argc, char *argv[])
+int main(int argc, char *argv[])
 {
 //intialisation
   ReadCommandLine(argv);
@@ -1058,7 +1069,7 @@ main(int argc, char *argv[])
     SDL_Delay(3000);
     SDL_UpdateRect(Screen,50,380,700,90);
   }
-  for (i=0;i<=NUMBER_OF_LEVELS;i++) {
+  for (i=0;i<=NUMBER_OF_LEVELS[levelset];i++) {
     int x,y;
     
     finished[i]=0;
@@ -1075,12 +1086,12 @@ main(int argc, char *argv[])
   Menu();
   while (mode!=3)
   {
-    levelnum=abrand(0,NUMBER_OF_LEVELS-1);
+    levelnum=abrand(0,NUMBER_OF_LEVELS[levelset]-1);
     sprintf(text,"BumpRace: Level #%d",levelnum);
     SDL_WM_SetCaption(text,"BumpRace");
     for (pl=0;pl<playernum;pl++) {user[pl].racernum=0;user[pl].points=0;}
     lifetime=800000;Score=0;levels_completed=0;Stage=1;
-    for (i=0;i<=NUMBER_OF_LEVELS;i++)
+    for (i=0;i<=NUMBER_OF_LEVELS[levelset];i++)
 	finished[i]=0;
     // select racer
     if (final) 
@@ -1145,4 +1156,6 @@ main(int argc, char *argv[])
   printf("Awaiting SDL_Quit()\n");
   SDL_Quit();
   printf("SDL_Quit() finished.\n");
-}
\ No newline at end of file
+  
+  return 0;
+}
